@@ -1,67 +1,65 @@
 
-import sys
+import glob
+import gzip
+import itertools
+import numbers
 import os
 import shutil
-import glob
-import itertools
+import sys
+import tarfile
 import warnings
-import numpy as np
-from numpy.lib.recfunctions import rename_fields as np_rename_fields
-from numpy.lib.recfunctions import append_fields as np_append_fields
-from scipy.interpolate import griddata
-from shapely import wkt
-from shapely.geometry import Point, Polygon, MultiPoint, MultiPolygon, LineString, MultiLineString, LinearRing, box, mapping, shape
-from shapely.ops import transform, linemerge, unary_union, polygonize
-from shapely.affinity import translate
-import pandas as pd
-import geopandas as gpd
-import rasterio as rio
-from rasterio.warp import calculate_default_transform, reproject, Resampling
-from rasterio.windows import get_data_window
-import xarray as xa
-import rioxarray as rxa
-import pyproj as Proj
+import webbrowser
+import zipfile
 from functools import partial
+
 import contextily as ctx
-import matplotlib.pyplot as plt
+import folium
+import geopandas as gpd
+import jenkspy
 import matplotlib.colors as colors
-import matplotlib.patches as mpatches
-import matplotlib.lines as mlines
 import matplotlib.legend as mlegend
+import matplotlib.lines as mlines
+import matplotlib.patches as mpatches
+import matplotlib.pyplot as plt
+import netCDF4 as nc
+import numpy as np
+import osmnx as osm
+import pandas as pd
+import pyproj as Proj
+import rasterio as rio
+import rioxarray as rxa
+import utm
+import xarray as xa
 from matplotlib.collections import PatchCollection
+from matplotlib.font_manager import FontProperties
 from matplotlib.path import Path
 from matplotlib.textpath import TextToPath
-from matplotlib.font_manager import FontProperties
 from mpl_toolkits.axes_grid1 import make_axes_locatable
-import webbrowser
-
+from numpy.lib.recfunctions import append_fields as np_append_fields
+from numpy.lib.recfunctions import rename_fields as np_rename_fields
+from rasterio.warp import Resampling, calculate_default_transform, reproject
+from rasterio.windows import get_data_window
+from scipy.interpolate import griddata, interp1d
+from shapely import wkt
+from shapely.affinity import translate
+from shapely.geometry import (LinearRing, LineString, MultiLineString,
+                              MultiPoint, MultiPolygon, Point, Polygon, box,
+                              mapping, shape)
+from shapely.ops import linemerge, polygonize, transform, unary_union
 from skimage.measure import find_contours
-from scipy.interpolate import interp1d
-import jenkspy
-
-import zipfile
-import tarfile
-import gzip
-import netCDF4 as nc
-import utm
-import numbers
-import osmnx as osm
-import folium
 from xarray.core import variable
 
-from lfmaptools.utilities import (_nice_round,
-                                  _represents_int,
-                                  latlon_to_utm_epsg,
-                                  _path_of_file_in_zip,
-                                  csv_active_cols,
-                                  csv_num_cols,
-                                  _decompress_gz)
-from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min, nc_min_max
-from lfmaptools.geotools import EastingNorthing_TM, LatLon_TM_polygonize, LatLon_TM
 from lfmaptools.demtools import load_dem, load_hillshade
 from lfmaptools.epsg_defs import webmerc, wgs84
-from lfmaptools.mapping import add_stamen_basemap
+from lfmaptools.geotools import (EastingNorthing_TM, LatLon_TM,
+                                 LatLon_TM_polygonize)
 from lfmaptools.interptools import interp_weights, interpolate
+from lfmaptools.mapping import add_stamen_basemap
+from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min, nc_min_max
+from lfmaptools.utilities import (_decompress_gz, _nice_round,
+                                  _path_of_file_in_zip, _represents_int,
+                                  csv_active_cols, csv_num_cols,
+                                  latlon_to_utm_epsg)
 
 _LFoutput_fmt = [
     {'file': 'all', 'column': 0, 'short_name': 'tile', 'long_name': 'tile id', 'symbol': None, 'units': 'dimensionless', 'dtype': int, 'infile': True, },
@@ -87,8 +85,8 @@ _LFoutput_fmt = [
     {'file': 'MaxHeights.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum depth', 'symbol': 't_maxh', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 5, 'short_name': 'maximum_speed', 'long_name': 'Maximum speed of lahar', 'symbol': 'maxspd', 'units': 'm/s', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum speed', 'symbol': 't_maxspd', 'units': 's', 'dtype': 'real', 'infile': True, },
-    {'file': 'MaxEorsion.txt', 'column': 5, 'short_name': 'maximum_erosion', 'long_name': 'Maximum erosion', 'symbol': 'maxero', 'units': 'm', 'dtype': 'real', 'infile': True, },
-    {'file': 'MaxEorsion.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum erosion', 'symbol': 't_maxero', 'units': 's', 'dtype': 'real', 'infile': True, },
+    {'file': 'MaxErosion.txt', 'column': 5, 'short_name': 'maximum_erosion', 'long_name': 'Maximum erosion', 'symbol': 'maxero', 'units': 'm', 'dtype': 'real', 'infile': True, },
+    {'file': 'MaxErosion.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum erosion', 'symbol': 't_maxero', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'InundationTime.txt', 'column': 5, 'short_name': 'inundation_time', 'long_name': 'Time of first inundation', 'symbol': 't_inun', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'Maximums.nc', 'short_name': 'maximum_depth', 'long_name': 'Maximum depth of lahar', 'symbol': 'maxh', 'units': 'm', 'dtype': 'real', 'infile': True, },
     {'file': 'Maximums.nc', 'short_name': 'time_of_max_depth', 'long_name': 'Time of the maximum depth', 'symbol': 't_maxh', 'units': 's', 'dtype': 'real', 'infile': True, },
@@ -1050,20 +1048,24 @@ class LaharFlowData(object):
             self.MaxDepth = m['maximum_depth']
             self.MaxSpeed = m['maximum_speed']
             self.MaxConc = m['maximum_concentration']
+            self.MaxErosion = m['maximum_erosion']
+            # self.MaxDeposit = m['maximum_deposit']
         except:
             self.MaxDepth = None
             self.MaxSpeed = None
             self.MaxConc = None
+            # self.MaxDeposit = None
+            self.MaxErosion = None
 
         last_outfile = self._snapshot_nc_files()[-1]
         LaharFlowFile = self._extract_file(last_outfile)
         try:
             maxE, maxD = nc_min_max(LaharFlowFile, var='elevation_change')
             self.MaxDeposit = maxD['elevation_change']
-            self.MaxErosion = -maxE['elevation_change']
+            # self.MaxErosion = -maxE['elevation_change']
         except:
             self.MaxDeposit = None
-            self.MaxErosion = None
+            # self.MaxErosion = None
         return
 
     def _get_max_erosion(self):
